A client side implementation of the Incremental Font Transfer standard https://w3c.github.io/IFT/Overview.html#glyph-keyed
More specifically this provides:
- Implementation of parsing and reading incremental font patch mappings: https://w3c.github.io/IFT/Overview.html#font-format-extensions
- Implementation of parsing and apply incremental font patches: https://w3c.github.io/IFT/Overview.html#font-patch-formats
Built on top of the read-fonts crate.
Modules
- font_
patch - Reads and applies font patches to font binaries.
- glyph_
keyed - Implementation of Glyph Keyed patch application.
- patch_
group - API for selecting and applying a group of IFT patches.
- patchmap
- Loads incremental font transfer https://w3c.github.io/IFT/Overview.html patch mappings.
- table_
keyed - Implementation of Table Keyed patch application.
- url_
templates - Implementation of the specific variant of URL template expansion required by the IFT specification.