Module font_patch

Module font_patch 

Reads and applies font patches to font binaries.

Font patch formats are defined as part of the incremental font transfer specification: https://w3c.github.io/IFT/Overview.html#font-patch-formats

Two main types of font patches are implemented:

  1. Table Keyed Patch - these patches contain a per table brotli binary patch to be applied to the input font.
  2. Glyph Keyed - these patches contain blobs of data associated with combinations of glyph id + table. The patch inserts these blobs into the table at the location for the corresponding glyph id.

Enums

PatchingError
An error that occurs while trying to apply an IFT patch to a font file.

Traits

IncrementalFontPatchBase
A trait for types to which an incremental font transfer patch can be applied.