Module patch_group

Module patch_group 

API for selecting and applying a group of IFT patches.

This provides methods for selecting a maximal group of patches that are compatible with each other and additionally methods for applying that group of patches.

Structs

OrderedPatchUrl
For non invalidating patches the specification requires they be ordered by entry order.
PatchGroup
A group of patches derived from a single IFT font.
PatchInfo
Tracks information related to a patch necessary to apply that patch.

Enums

UrlStatus
Tracks whether a URL has already been applied to a font or not.