pub struct OrderedPatchUrl(/* private fields */);Expand description
For non invalidating patches the specification requires they be ordered by entry order.
That is the order that the physical entries in the patch map are in. This struct adds that ordering onto PatchUrl’s for when they are stored in a btree set/map. Context: https://github.com/w3c/IFT/pull/279