pub fn intersecting_patches(
font: &FontRef<'_>,
subset_definition: &SubsetDefinition,
) -> Result<Vec<PatchMapEntry>, ReadError>Expand description
Find the set of patches which intersect the specified subset definition.
pub fn intersecting_patches(
font: &FontRef<'_>,
subset_definition: &SubsetDefinition,
) -> Result<Vec<PatchMapEntry>, ReadError>Find the set of patches which intersect the specified subset definition.