Loads incremental font transfer https://w3c.github.io/IFT/Overview.html patch mappings.
The IFT and IFTX tables encode mappings from subset definitions to URL’s which host patches that can be applied to the font to add support for the corresponding subset definition.
Structs
- Patch
MapEntry - Stores a collection of URLs associated with each patch mapping entry.
- Patch
Url - An expanded PatchUrl string which identifies where a patch is located.
- Subset
Definition - Stores a description of a font subset over codepoints, feature tags, and design space.
Enums
- Design
Space - Stores a collection of ranges across zero or more axes.
- Feature
Set - Stores a set of features tags, can additionally represent all features.
- Patch
Format - Models the encoding type for a incremental font transfer patch. See: https://w3c.github.io/IFT/Overview.html#font-patch-formats-summary
- PatchId
- Id for a patch which will be subbed into a URL template. The spec allows integer or string IDs.
Functions
- intersecting_
patches - Find the set of patches which intersect the specified subset definition.