PatchMapEntry

Struct PatchMapEntry 

pub struct PatchMapEntry { /* private fields */ }
Stores a collection of URLs associated with each patch mapping entry.

Each entry has a primary URL which is what is loaded and applied when the entry is selected. Additionally each entry has an optional set of preload URL’s which should be preloaded if the entry is selected

Implementations

Source

impl PatchMapEntry

pub fn url(&self) -> &PatchUrl

pub fn format(&self) -> PatchFormat